package java.security;

import java.io.IOException;
import java.io.OutputStream;
import java.io.FilterOutputStream;

public class DigestOutputStream extends FilterOutputStream
{
    private boolean on;
    protected MessageDigest digest;
    
    public DigestOutputStream(OutputStream out, MessageDigest messageDigest) {
        super(out);
        this.on = true;
        this.setMessageDigest(messageDigest);
    }
    
    public MessageDigest getMessageDigest() {
        return this.digest;
    }
    
    public void setMessageDigest(MessageDigest digest) {
        this.digest = digest;
    }
    
    @Override
    public void write(int n) throws IOException {
        this.out.write(n);
        if (this.on) {
            this.digest.update((byte)n);
        }
    }
    
    @Override
    public void write(byte[] b, int off, int len) throws IOException {
        this.out.write(b, off, len);
        if (this.on) {
            this.digest.update(b, off, len);
        }
    }
    
    public void on(boolean on) {
        this.on = on;
    }
    
    @Override
    public String toString() {
        return "[Digest Output Stream] " + this.digest.toString();
    }
}
